@@ -13,7 +13,7 @@
 
 from oslo_log import log as logging
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import tabs
